This example shows how to add some simple views to your admin interface.
The views do not have to be associated to any of your models, and you can fill them with whatever content you want.

To run this example:

1. Clone the repository::

    git clone https://github.com/flask-admin/flask-admin.git
    cd flask-admin

2. Create and activate a virtual environment::

    virtualenv env
    source env/bin/activate

3. Install requirements::

    pip install -r 'examples/simple/requirements.txt'

4. Run the application::

    python examples/simple/app.py
